@@ -1,5 +1,5 @@
 import re
-from flask import Blueprint
+from flask import Blueprint, request
 from flask.ext.babelpkg import gettext, ngettext, lazy_gettext
 from forms import GeneralModelConverter
 from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget, ListCarousel
@@ -314,7 +314,7 @@ class BaseCRUDView(BaseModelView):
             class MyView(GeneralView):
                 datamodel = SQLAModel(MyTable, db.session)
 
-                description_columns = {'name','your models name column','address','the address column'}
+                description_columns = {'name':'your models name column','address':'the address column'}
     """
     validators_columns = None
     """ Dictionary to add your own validators for forms """
